@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.008001;
 use parent qw(Exporter);
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use Unicode::EastAsianWidth;
 
 our @EXPORT_OK = qw(vwidth vtrim);
@@ -13,6 +13,8 @@ our $EastAsian = $Unicode::EastAsianWidth::EastAsian;
 sub Spacing {
     $_[0] . <<END
 -utf8::Nonspacing_Mark
+-utf8::Enclosing_Mark
+-utf8::Default_Ignorable_Code_Point
 END
 }
 
@@ -62,23 +64,24 @@ sub trim {
 
     my $cnt = 0;
     my $ret = '';
+    my $fullwidth = $EastAsian ? qr/\p{InVWPP1Fullwidth}/ : qr/\p{InVWPP0Fullwidth}/;
     while ($str =~ /\G(\X)/g) {
-	my $ch = $1;
-	my $w = do {
-	    if ($ch =~ /\p{InFullwidth}/) {
-		2;
-	    } elsif (length($ch) == 1) {
-		1;
-	    } else {
-		width($ch);
-	    }
-	};
-	if ($cnt+$w <= $limit) {
-	    $ret .= $ch;
-	    $cnt += $w;
-	} else {
-	    last;
-	}
+        my $ch = $1;
+        my $w = do {
+            if ($ch =~ /\A$fullwidth\z/) {
+                2;
+            } elsif (length($ch) == 1) {
+                1;
+            } else {
+                width($ch);
+            }
+        };
+        if ($cnt+$w <= $limit) {
+            $ret .= $ch;
+            $cnt += $w;
+        } else {
+            last;
+        }
     }
     $ret;
 }
@@ -92,7 +95,7 @@ __END__
 
 =head1 NAME
 
-Text::VisualWidth::PP - trimming text by the number of the column s of terminals and mobile phones.
+Text::VisualWidth::PP - trimming text by the number of the columns of terminals and mobile phones.
 
 =head1 SYNOPSIS
 
